@@ -1,3 +1,5 @@
+import json.decoder
+
 import requests
 
 from akinoncli.core.exc import AkinonCLIError
@@ -75,7 +77,12 @@ class AkinonCloudClient:
                 f'API returned an unsuccessful status code. HTTP {response.status_code}: {response.reason}',
                 response=response)
 
-        data = response.json() if response_format == 'json' else response.content
+        data = response.content
+        if response_format == 'json':
+            try:
+                data = response.json()
+            except json.decoder.JSONDecodeError:
+                data = {}
 
         return AkinonResponse(is_succeed=response.ok,
                               status_code=response.status_code,
