@@ -67,9 +67,9 @@ class Projects(Controller):
         }
         response = self.app.client.create_project(data)
         if response.is_succeed:
-            self.app.render({}, renderer_type='text', custom_text="Project has been created.")
+            self.app.render("Project has been created.", renderer_type='text')
         else:
-            self.app.render({}, renderer_type='text', custom_text=response.data['slug'][0])
+            self.app.render(response.data['slug'][0], renderer_type='text')
 
     @ex(
         help='Project Update Command',
@@ -91,9 +91,9 @@ class Projects(Controller):
         }
         response = self.app.client.update_project(p_id, data)
         if response.is_succeed:
-            self.app.render({}, renderer_type='text', custom_text="Project has been updated.")
+            self.app.render("Project has been updated.", renderer_type='text')
         else:
-            self.app.render({}, renderer_type='text', custom_text=response.data)
+            self.app.render(response.data, renderer_type='text')
 
 
 class ProjectApps(Controller):
@@ -174,7 +174,7 @@ class ProjectApps(Controller):
                                      'created_date': 'Created Date', 'env': 'ENV Variables'},
                             is_succeed=response.is_succeed)
         else:
-            self.app.render({}, renderer_type='text', custom_text=response.data)
+            self.app.render(response.data, renderer_type='text')
 
     @ex(
         help='Project App Remove Environment Value Command',
@@ -218,12 +218,12 @@ class ProjectApps(Controller):
             for key, value in row['custom_env'].items():
                 row['env'] += f'{key}={value}\n'
 
-            self.app.render(data=response.data, rows=[row],
+            self.app.render(response.data, rows=[row],
                             headers={'pk': 'ID', 'project': 'Project', 'app': 'App',
                                      'created_date': 'Created Date', 'env': 'ENV Variables'},
                             is_succeed=response.is_succeed)
         else:
-            self.app.render({}, renderer_type='text', custom_text=response.data)
+            self.app.render(response.data, renderer_type='text')
 
     @ex(
         help='Project App Add Command',
@@ -246,9 +246,9 @@ class ProjectApps(Controller):
         }
         response = self.app.client.create_project_app(p_id, data)
         if response.is_succeed:
-            self.app.render({}, renderer_type='text', custom_text="App has been added to the project.")
+            self.app.render("App has been added to the project.", renderer_type='text')
         else:
-            self.app.render({}, renderer_type='text', custom_text=response.data)
+            self.app.render(response.data, renderer_type='text')
 
     @ex(
         help='Project App Deploy Command',
@@ -276,9 +276,9 @@ class ProjectApps(Controller):
         response = self.app.client.deploy_project_app(p_id, pa_id, data=data)
 
         if response.is_succeed:
-            self.app.render({}, renderer_type='text', custom_text="ProjectApp deployment has been started.")
+            self.app.render("ProjectApp deployment has been started.", renderer_type='text')
         else:
-            self.app.render({}, renderer_type='text', custom_text=response.data['non_field_errors'])
+            self.app.render(response.data['non_field_errors'], renderer_type='text')
 
     @ex(
         help='Multiple Project App Deploy Command',
@@ -313,9 +313,9 @@ class ProjectApps(Controller):
         }
         response = self.app.client.deploy_multiple_project_apps(self.app.pargs.app_id, data)
         if response.is_succeed:
-            self.app.render({}, renderer_type='text', custom_text="ProjectApp deployments have been started.")
+            self.app.render("ProjectApp deployments have been started.", renderer_type='text')
         else:
-            self.app.render({}, renderer_type='text', custom_text=response.data["non_field_errors"])
+            self.app.render(response.data["non_field_errors"], renderer_type='text')
 
     @ex(
         help='Project App Deployment List Command',
@@ -388,12 +388,9 @@ class ProjectApps(Controller):
         response = self.app.client.update_project_app(p_id, pa_id, data=data)
 
         if response.is_succeed:
-            self.app.render({}, renderer_type='text',
-                            custom_text="Certificate has been attached"
-                                        " to project app.")
+            self.app.render("Certificate has been attached to project app.", renderer_type='text')
         else:
-            self.app.render({}, renderer_type='text',
-                            custom_text=response.data['non_field_errors'])
+            self.app.render(response.data['non_field_errors'], renderer_type='text')
 
     @ex(
         help='Detach Certificate to Project App',
@@ -417,12 +414,9 @@ class ProjectApps(Controller):
         response = self.app.client.update_project_app(p_id, pa_id, data=data)
 
         if response.is_succeed:
-            self.app.render({}, renderer_type='text',
-                            custom_text="Certificate has been detached"
-                                        " from project app.")
+            self.app.render("Certificate has been detached from project app.", renderer_type='text')
         else:
-            self.app.render({}, renderer_type='text',
-                            custom_text=response.data['non_field_errors'])
+            self.app.render(response.data['non_field_errors'], renderer_type='text')
 
     @ex(
         help='Get Project App Logs',
@@ -460,9 +454,8 @@ class ProjectApps(Controller):
             )
         else:
             self.app.render(
-                data={},
-                renderer_type="text",
-                custom_text="No logs found in 1 minute",
+                "No logs found in 1 minute",
+                renderer_type="text"
             )
 
     @ex(
@@ -509,7 +502,7 @@ class ProjectApps(Controller):
             else:
                 raise
 
-        self.app.render({}, custom_text=response.data['message'], renderer_type='text')
+        self.app.render(response.data['message'], renderer_type='text')
 
 
 class Addons(Controller):
