@@ -1,40 +1,47 @@
-import os
+from datetime import timedelta
+from pathlib import Path
 
-from akinoncli.controllers.clusters import KubeMetricMonitor
-from tinydb import TinyDB
-from cement.utils import fs
-from cement import App, TestApp, init_defaults
+from cement import App, TestApp
 from cement.core.exc import CaughtSignal
+from tinydb import TinyDB
 
-from akinoncli.controllers.account import Domains, Certificates
-from akinoncli.ext.output_renderer import AkinonOutputHandler
 from akinoncli.client.client import AkinonCloudClient
-from akinoncli.core.exc import AkinonCLIError, AkinonCLIWarning
-
-from akinoncli.controllers.base import Base
-from akinoncli.controllers.auth import Auth
-# from .controllers.clusters import Clusters
-from akinoncli.controllers.projects import Projects, ProjectApps, Addons
+from akinoncli.controllers.account import Domains, Certificates
 from akinoncli.controllers.applications import Applications, ApplicationTypes
-# from .controllers.applications import ApplicationUsers
+from akinoncli.controllers.auth import Auth
+from akinoncli.controllers.base import Base
+from akinoncli.controllers.clusters import KubeMetricMonitor
+from akinoncli.controllers.projects import Projects, ProjectApps, Addons
 from akinoncli.controllers.public_keys import PublicKeys
+from akinoncli.core.exc import AkinonCLIError, AkinonCLIWarning
+from akinoncli.core.version import get_version
+from akinoncli.ext.output_renderer import AkinonOutputHandler
+from akinoncli.ext.update_checker import ThrottledUpdateChecker, TinyDbStorage
 
-# from .controllers.users import Users, Roles
 
-# configuration defaults
-CONFIG = init_defaults('akinoncli')
-CONFIG['akinoncli']['db_file'] = '~/.akinoncli/db.json'
+db_path = Path('~/.akinoncli/db.json').expanduser().resolve()
+
+
+def get_db() -> TinyDB:
+    db_path.parent.mkdir(parents=True, exist_ok=True)
+    return TinyDB(db_path)
+
+
+def check_updates(*_):
+    db = get_db()
+    checker = ThrottledUpdateChecker(
+        package_name='akinoncli',
+        duration=timedelta(hours=1),
+        storage=TinyDbStorage(db)
+    )
+    new_version = checker.check(current_version=get_version())
+    if not new_version:
+        return
+    print('A new version is available: {}'.format(new_version.version))
 
 
 def extend_tinydb(app):
-    db_file = app.config.get('akinoncli', 'db_file')
-    db_file = fs.abspath(db_file)
-    # ensure our parent directory exists
-    db_dir = os.path.dirname(db_file)
-    if not os.path.exists(db_dir):
-        os.makedirs(db_dir)
-
-    app.extend('db', TinyDB(db_file))
+    app.extend('db', get_db())
 
 
 def extend_client(app):
@@ -55,9 +62,6 @@ class AkinonCLI(App):
     class Meta:
         label = 'akinoncli'
 
-        # configuration defaults
-        config_defaults = CONFIG
-
         # call sys.exit() on close
         exit_on_close = True
 
@@ -100,6 +104,7 @@ class AkinonCLI(App):
         ]
 
         hooks = [
+            ('pre_setup', check_updates),
             ('post_setup', extend_tinydb),
             ('post_setup', extend_client),
         ]
